==> eztrace_0.7-2.orig.tar.gz: eztrace-0.7-2/src/modules/mpi/mpi_funcs/mpi_rsend_init.c <==
/* -*- c-file-style: "GNU" -*- */
/*
 * Copyright © CNRS, INRIA, Université Bordeaux 1
 * See COPYING in top-level directory.
 */

#define _GNU_SOURCE 1
#define _REENTRANT

#include <unistd.h>
#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>
#include <sys/time.h>
#include <sys/timeb.h>
#include <dlfcn.h>
#include <string.h>

#include "mpi.h"
#include "mpi_eztrace.h"
#include "mpi_ev_codes.h"
#include "eztrace.h"


static int MPI_Rsend_init_core(void* buffer, int count, MPI_Datatype type, int dest, int tag,
			       MPI_Comm comm, MPI_Request *req)
{
  return libMPI_Rsend_init(buffer, count, type, dest, tag, comm, req);
}

static void MPI_Rsend_init_epilog(void* buffer, int count, MPI_Datatype type, int dest, int tag,
				  MPI_Comm comm, MPI_Fint *req)
{
  int size;
  MPI_Type_size(type, &size);
  EZTRACE_EVENT3(FUT_MPI_RSEND_INIT, buffer, count*size, dest);
  EZTRACE_EVENT3(FUT_MPI_Info, tag, comm, req);
}

int MPI_Rsend_init(void* buffer, int count, MPI_Datatype type, int dest, int tag,
		   MPI_Comm comm, MPI_Request *req)
{
  FUNCTION_ENTRY;
  int ret = MPI_Rsend_init_core(buffer, count, type, dest, tag, comm, req);
  MPI_Rsend_init_epilog(buffer, count, type, dest, tag, comm, req);
  return ret;
}


void mpif_rsend_init_ (void*buffer, int*count, MPI_Fint*type, int*dest, int*tag,
		       MPI_Fint*comm, MPI_Fint *req, int*error)
{
  MPI_Datatype c_type = MPI_Type_f2c(*type);
  MPI_Comm c_comm = MPI_Comm_f2c(*comm);
  MPI_Request c_req = MPI_Request_f2c(*req);

  *error = MPI_Rsend_init_core(buffer, *count, c_type, *dest, *tag, c_comm, &c_req);
  *req = MPI_Request_c2f(c_req);
  MPI_Rsend_init_epilog(buffer, *count, c_type, *dest, *tag, c_comm, req);
}

==> eztrace_0.9.1.orig.tar.gz: eztrace-0.9.1/src/modules/mpi/mpi_funcs/mpi_rsend_init.c <==
/* -*- c-file-style: "GNU" -*- */
/*
 * Copyright © CNRS, INRIA, Université Bordeaux 1
 * See COPYING in top-level directory.
 */

#define _GNU_SOURCE 1
#define _REENTRANT

#include <unistd.h>
#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>
#include <sys/time.h>
#include <sys/timeb.h>
#include <dlfcn.h>
#include <string.h>

#include "mpi.h"
#include "mpi_eztrace.h"
#include "mpi_ev_codes.h"
#include "eztrace.h"


static int MPI_Rsend_init_core(CONST void* buffer, int count, MPI_Datatype type, int dest, int tag,
			       MPI_Comm comm, MPI_Request *req)
{
  return libMPI_Rsend_init(buffer, count, type, dest, tag, comm, req);
}

static void MPI_Rsend_init_epilog(CONST void* buffer, int count, MPI_Datatype type, int dest, int tag,
				  MPI_Comm comm, MPI_Fint *req)
{
  int size;
  MPI_Type_size(type, &size);
  EZTRACE_EVENT3(FUT_MPI_RSEND_INIT, buffer, count*size, dest);
  EZTRACE_EVENT3(FUT_MPI_Info, tag, comm, req);
}

int MPI_Rsend_init(CONST void* buffer, int count, MPI_Datatype type, int dest, int tag,
		   MPI_Comm comm, MPI_Request *req)
{
  FUNCTION_ENTRY;
  int ret = MPI_Rsend_init_core(buffer, count, type, dest, tag, comm, req);
  MPI_Rsend_init_epilog(buffer, count, type, dest, tag, comm, (MPI_Fint*)req);
  return ret;
}


void mpif_rsend_init_ (void*buffer, int*count, MPI_Fint*type, int*dest, int*tag,
		       MPI_Fint*comm, MPI_Fint *req, int*error)
{
  MPI_Datatype c_type = MPI_Type_f2c(*type);
  MPI_Comm c_comm = MPI_Comm_f2c(*comm);
  MPI_Request c_req = MPI_Request_f2c(*req);

  *error = MPI_Rsend_init_core(buffer, *count, c_type, *dest, *tag, c_comm, &c_req);
  *req = MPI_Request_c2f(c_req);
  MPI_Rsend_init_epilog(buffer, *count, c_type, *dest, *tag, c_comm, req);
}
